.. :changelog:

Release Log
-----------

0.0.1 (2015-12-17)
^^^^^^^^^^^^^^^^^^

* First release on PyPI.
   + Docs need updating and more usage.
   + Corralling is functional, but does not use nickname expansions.
   + Some tweaking of probabilities could be attempted for certain scenarios.
   + Probabilities are generated using birth year, name fields, address, and
     zip code.

0.0.2 (2015-12-17)
^^^^^^^^^^^^^^^^^^

* Update documentation.
   + Add significant documentation of matching algorithm in Overview docs.
   + Fix up code examples in Usage docs.

0.0.3 (2015-12-17)
^^^^^^^^^^^^^^^^^^

* Another update to documentation.
   + The previous release had some minor docs stuff missing.
